@@ -7,6 +7,7 @@ our $PERL_VERSION = $^V;
 $PERL_VERSION =~ s|^v||;
 
 use OpenGL qw/ :all /;
+use OpenGL::Config;     # for build information
 
 eval 'use OpenGL::Image 1.03';  # Need to use OpenGL::Image 1.03 or higher!
 my $hasImage = !$@;
@@ -18,7 +19,12 @@ my $hasShader = !$@;
 eval 'use Image::Magick';
 my $hasIM = !$@;
 
-use Math::Trig;
+# This does not seem to be needed and it adds an extra, unneeded
+# dependency to the build process.  Leaving this in as a comment
+# just in case it is being used somewhere here
+#
+# use Math::Trig;
+
 eval 'use Time::HiRes qw( gettimeofday )';
 my $hasHires = !$@;
 $|++;
@@ -66,7 +72,7 @@ use constant DO_TESTS => 0;
 
 # Run in Game Mode
 my $gameMode;
-if ($#ARGV and lc($ARGV[0]) eq 'gamemode')
+if (scalar(@ARGV) and lc($ARGV[0]) eq 'gamemode')
 {
   $gameMode = $ARGV[1] || '';
 }
@@ -86,7 +92,7 @@ my $hasVBO = 0;
 my $hasFragProg = 0;
 my $hasImagePointer = 0;
 my $idleTime = time();
-my $idleSecsMax = 30;
+my $idleSecsMax = 5;
 my $er;
 
 # Window and texture IDs, window width and height.
@@ -1220,7 +1226,7 @@ sub cbKeyPressed
   elsif ($c eq 'K')
   {
     # ignore keypress if not FreeGLUT
-    glutLeaveMainLoop() if $OpenGL::_have_freeglut;
+    glutLeaveMainLoop() if OpenGL::_have_freeglut();
   }
   elsif ($c eq 'L')
   {
@@ -1485,7 +1491,7 @@ glutInit();
 # To see OpenGL drawing, take out the GLUT_DOUBLE request.
 glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH | GLUT_ALPHA);
 
-if ($^O ne 'MSWin32') { # skip these MODE checks on win32, they don't work
+if ($^O ne 'MSWin32' and $OpenGL::Config->{DEFINE} !~ /-DHAVE_W32API/) { # skip these MODE checks on win32, they don't work
 
    if (not glutGet(GLUT_DISPLAY_MODE_POSSIBLE))
    {
@@ -1582,7 +1588,7 @@ glutMouseFunc(\&cbMouseClick);
 #glutPassiveMotionFunc(\&cbMouseTrack);
 
 # Handle window close events.
-glutCloseFunc(\&cbClose) if $OpenGL::_have_freeglut;
+glutCloseFunc(\&cbClose) if OpenGL::_have_freeglut();
 
 # OK, OpenGL's ready to go.  Let's call our own init function.
 ourInit($Window_Width, $Window_Height);
@@ -1602,7 +1608,7 @@ Press 'c' to capture/save a RGBA targa file.
 
 # Pass off control to OpenGL.
 # Above functions are called as appropriate.
-if ($OpenGL::_have_freeglut) {
+if (OpenGL::_have_freeglut()) {
    glutSetOption(GLUT_ACTION_ON_WINDOW_CLOSE,GLUT_ACTION_GLUTMAINLOOP_RETURNS)
 }
 
